mapxus_positioning_flutter library

Classes

MapxusPositioningFlutter
Singleton wrapper for the MapxusPositioningFlutter plugin.

Typedefs

MapxusBackgroundHandler = Future<void> Function(MapxusEvent event)
Signature for the function called by the foreground service when a positioning event arrives and the app is closed.