isIgnoringBatteryOptimizations method

Future<bool> isIgnoringBatteryOptimizations()

Returns true if the app is already exempt from Android battery optimizations. Some OEMs (Transsion/Tecno/Infinix, Xiaomi, etc.) kill the foreground service in the background regardless of manifest flags unless the app is explicitly whitelisted.

Implementation

Future<bool> isIgnoringBatteryOptimizations() =>
    _platform.isIgnoringBatteryOptimizations();