stopForegroundService method
Stops the foreground service and removes the persistent notification.
Implementation
Future<MapxusMethodResponse> stopForegroundService() =>
_platform.stopForegroundService();
Stops the foreground service and removes the persistent notification.
Future<MapxusMethodResponse> stopForegroundService() =>
_platform.stopForegroundService();