PositioningOrientationEvent class

Inheritance

Constructors

PositioningOrientationEvent({double? orientation, int? accuracy})
PositioningOrientationEvent.fromMap(Map map)
factory

Properties

accuracy → int?
final
hashCode → int
The hash code for this object.
no setterinherited
orientation → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited