MapxusSensorResultModel class

Constructors

MapxusSensorResultModel({required int statusCode, required String message})
MapxusSensorResultModel.fromMap(Map map)
Factory constructor to create from Map (from platform channel)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert to Map (useful if you send it back to native)
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited