isForegroundServiceRunning method
Returns true if the Android foreground service is currently running.
Call this in initState to restore isForegroundServiceRunning state
after the app was killed and reopened while the service was active.
Implementation
Future<bool> isForegroundServiceRunning() =>
_platform.isForegroundServiceRunning();